#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Jul 16 20:32:03 2020

@author: xiao
"""
#from .gui import main_gui
# from gui import tomo_gui, xanes2D_gui, xanes3D_gui
# __all__ = [txm, tomo_gui, xanes2D_gui, xanes3D_gui]


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Jul 16 22:20:14 2020

@author: xiao
"""

from setuptools import setup

setup(name='TXM_Sandbox',
      version='0.1.1',
      description='Integrated Spectro-Imaging Analysis Toolbox',
      url='https://github.com/xianghuix/TXM_Sandbox',
      author='Xianghui Xiao',
      author_email='xianghuix@gmail.com',
      license='MIT',
      packages=['TXM_Sandbox'],
      install_requires=[
            'python>=3.8',
            'openjdk==8',
            'pyimagej',
            'nodejs',
            'xarray',
            'tomopy',
            'h5py',
            'tifffile',
            'imutils',
            'opencv',
            'openpyxl',
            'pytables',
            'pandas',
            'jupyter',
            'jupyterlab',
            'multiprocess',
            'scikit-image',
            'scikit-learn',
            'pystackreg',
            'silx',
            'napari'
      ],
      zip_safe=False)
